# picklify
lib python para facilitar o uso de arquivos pickle no python


## Instalação
```
pip install picklify
```
## Como utilizar?

- ##### Acessando diretamente sadfsf
```python

```

## Dependências
- pyodbc
- pandas

## Dúvidas ou Sugestões
henriquespencer11@gmail.com
